@@ -333,10 +333,7 @@ void RedditSession::loginFinished()
     emit loginResponse(s);
     qDebug() << "loginfinish " << s;
 
-    if (RCookieJar* cj = qobject_cast<RCookieJar*>(m_net->cookieJar())) {
-        QSettings setts;
-        setts.setValue("Auth/Cookies", cj->store());
-    }
+    saveCookies();
 
 }
 
@@ -422,4 +419,27 @@ void RedditSession::getMyReddits()
 
 }
 
+void RedditSession::logout()
+{
+    cookieJar()->clear();
+    saveCookies();
+    m_myreddits.clear();
+    emit loggedOut();
+
+}
+
+RCookieJar * RedditSession::cookieJar()
+{
+    RCookieJar* cj = qobject_cast<RCookieJar*>(m_net->cookieJar());
+    return cj;
+}
+
+void RedditSession::saveCookies()
+{
+
+    QSettings setts;
+    setts.setValue("Auth/Cookies", cookieJar()->store());
+
+}
+
 
